@@ -1,21 +1,10 @@
-/***************************************************************************
- *   Copyright 2018  Thomas Baumgart  tbaumgart@kde.org                    *
- *                                                                         *
- *   This file is part of libalkimia.                                      *
- *                                                                         *
- *   libalkimia is free software; you can redistribute it and/or           *
- *   modify it under the terms of the GNU Lesser General Public License    *
- *   as published by the Free Software Foundation; either version 2.1 of   *
- *   the License or (at your option) version 3 or any later version.       *
- *                                                                         *
- *   libalkimia is distributed in the hope that it will be useful,         *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2018 Thomas Baumgart tbaumgart @kde.org
+
+    This file is part of libalkimia.
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "alkonlinequotesourcetest.h"
 
@@ -106,3 +95,39 @@ void AlkOnlineQuoteSourceTest::testReadWriteRemove()
     AlkOnlineQuoteSource m3("test-currency", &profile);
     QVERIFY(m3.url().isEmpty());
 }
+
+void AlkOnlineQuoteSourceTest::testRename()
+{
+    AlkOnlineQuotesProfile profile("test", AlkOnlineQuotesProfile::Type::Alkimia4);
+    AlkOnlineQuoteSource m1(
+        "test-currency",
+        "https://fx-rate.net/%1/%2",
+        QString(), // symbolregexp
+        "1[ a-zA-Z]+=</span><br */?> *(\\d+\\.\\d+)",
+        "updated\\s\\d+:\\d+:\\d+\\(\\w+\\)\\s+(\\d{1,2}/\\d{2}/\\d{4})",
+        "%d/%m/%y",
+        true // skip HTML stripping
+    );
+    m1.setProfile(&profile);
+    m1.write();
+    m1.rename("test-currency.new");
+
+    // should be the same
+    AlkOnlineQuoteSource m2("test-currency.new", &profile);
+    QCOMPARE(m1.name(),          m2.name());
+    QCOMPARE(m1.isValid(),       m2.isValid());
+    QCOMPARE(m1.url(),           m2.url());
+    QCOMPARE(m1.sym(),           m2.sym());
+    QCOMPARE(m1.price(),         m2.price());
+    QCOMPARE(m1.date(),          m2.date());
+    QCOMPARE(m1.dateformat(),    m2.dateformat());
+    QCOMPARE(m1.skipStripping(), m2.skipStripping());
+    QCOMPARE(m1.isGHNS(),        m2.isGHNS());
+
+    // should be empty
+    AlkOnlineQuoteSource m3("test-currency", &profile);
+    QVERIFY(m3.url().isEmpty());
+
+    // cleanup
+    m1.remove();
+}
