@@ -1,21 +1,10 @@
-/***************************************************************************
- *   Copyright 2010  Thomas Baumgart  ipwizard@users.sourceforge.net       *
- *                                                                         *
- *   This file is part of libalkimia.                                      *
- *                                                                         *
- *   libalkimia is free software; you can redistribute it and/or           *
- *   modify it under the terms of the GNU Lesser General Public License    *
- *   as published by the Free Software Foundation; either version 2.1 of   *
- *   the License or (at your option) version 3 or any later version.       *
- *                                                                         *
- *   libalkimia is distributed in the hope that it will be useful,         *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Thomas Baumgart ipwizard @users.sourceforge.net
+
+    This file is part of libalkimia.
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "alkvaluetest.h"
 
@@ -465,6 +454,16 @@ void AlkValueTest::convertDenominator()
 
     a = AlkValue(1.9999999999998, 100);
     QCOMPARE(a, AlkValue(2, 1));
+
+    mpz_class denominator(1000000); // 10^6
+    denominator *= denominator; // 10^12
+    denominator *= denominator; // 10^24
+    const auto s = denominator.get_str();
+    QCOMPARE(QString::fromUtf8(s.data(), int(s.size())), QLatin1String("1000000000000000000000000"));
+    a = AlkValue(QLatin1String("1.123456789212345678931234567"), QLatin1Char('.'));
+    b = AlkValue(QLatin1String("1.123456789212345678931234"), QLatin1Char('.'));
+    QCOMPARE(a.toString(), QLatin1String("1123456789212345678931234567/1000000000000000000000000000"));
+    QCOMPARE(a.convertDenominator(denominator, AlkValue::RoundTruncate), b);
 }
 
 void AlkValueTest::convertPrecision()
