@@ -1,21 +1,10 @@
-/***************************************************************************
- *   Copyright 2018  Ralf Habacker <ralf.habacker@freenet.de>              *
- *                                                                         *
- *   This file is part of libalkimia.                                      *
- *                                                                         *
- *   libalkimia is free software; you can redistribute it and/or           *
- *   modify it under the terms of the GNU Lesser General Public License    *
- *   as published by the Free Software Foundation; either version 2.1 of   *
- *   the License or (at your option) version 3 or any later version.       *
- *                                                                         *
- *   libalkimia is distributed in the hope that it will be useful,         *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2018 Ralf Habacker ralf.habacker @freenet.de
+
+    This file is part of libalkimia.
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "alkonlinequotesource.h"
 
@@ -55,6 +44,7 @@ public:
         , m_skipStripping(other->m_skipStripping)
         , m_profile(other->m_profile)
         , m_isGHNSSource(other->m_isGHNSSource)
+        , m_storageChanged(other->m_storageChanged)
         , m_readOnly(other->m_readOnly)
     {
     }
@@ -227,7 +217,7 @@ AlkOnlineQuoteSource::AlkOnlineQuoteSource(const QString &name, const QString &u
 AlkOnlineQuoteSource::AlkOnlineQuoteSource(const QString &name, AlkOnlineQuotesProfile *profile)
     : d(new Private)
 {
-    if (profile->type() == AlkOnlineQuotesProfile::Type::None && profile->defaultQuoteSources().contains(name)) {
+    if ((profile != nullptr) && (profile->type() == AlkOnlineQuotesProfile::Type::None) && (profile->defaultQuoteSources().contains(name))) {
         *this = profile->defaultQuoteSources()[name];
     } else {
         d->m_profile = profile;
