@@ -1,22 +1,11 @@
-/***************************************************************************
- *   Copyright 2018  Ralf Habacker <ralf.habacker@freenet.de>              *
- *   Copyright 2019  Thomas Baumgart <tbaumgart@kde.org>                   *
- *                                                                         *
- *   This file is part of libalkimia.                                      *
- *                                                                         *
- *   libalkimia is free software; you can redistribute it and/or           *
- *   modify it under the terms of the GNU Lesser General Public License    *
- *   as published by the Free Software Foundation; either version 2.1 of   *
- *   the License or (at your option) version 3 or any later version.       *
- *                                                                         *
- *   libalkimia is distributed in the hope that it will be useful,         *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2018 Ralf Habacker ralf.habacker @freenet.de
+    SPDX-FileCopyrightText: 2019 Thomas Baumgart tbaumgart @kde.org
+
+    This file is part of libalkimia.
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #ifdef ENABLE_FINANCEQUOTE
 #include "alkfinancequoteprocess.h"
@@ -38,11 +27,13 @@
 
 #if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
     #include <QStandardPaths>
-    #include <kns3/downloadmanager.h>
+    #include <knscore/downloadmanager.h>
+    namespace KNS = KNSCore;
 #else
     #include <KGlobal>
     #include <KStandardDirs>
     #include <knewstuff3/downloadmanager.h>
+    namespace KNS = KNS3;
 #endif
 
 class AlkOnlineQuotesProfile::Private : public QObject
@@ -55,7 +46,7 @@ public:
     QString m_GHNSFilePath;
     QString m_kconfigFile;
     AlkOnlineQuotesProfileManager *m_profileManager;
-    KNS3::DownloadManager *m_manager;
+    KNS::DownloadManager *m_manager;
     KConfig *m_config;
     Type m_type;
     static QString m_financeQuoteScriptPath;
@@ -94,7 +85,7 @@ public:
 
     void checkUpdates()
     {
-        m_manager = new KNS3::DownloadManager(m_p->hotNewStuffConfigFile(), this);
+        m_manager = new KNS::DownloadManager(m_p->hotNewStuffConfigFile(), this);
         // to know when checking for updates is done
         connect(m_manager, SIGNAL(searchResult(KNS3::Entry::List)), this,
                 SLOT(slotUpdatesFound(KNS3::Entry::List)));
