@@ -1,21 +1,10 @@
-/***************************************************************************
- *   Copyright 2018 Ralf Habacker <ralf.habacker@freenet.de>               *
- *                                                                         *
- *   This file is part of libalkimia.                                      *
- *                                                                         *
- *   libalkimia is free software; you can redistribute it and/or           *
- *   modify it under the terms of the GNU Lesser General Public License    *
- *   as published by the Free Software Foundation; either version 2.1 of   *
- *   the License or (at your option) version 3 or any later version.       *
- *                                                                         *
- *   libalkimia is distributed in the hope that it will be useful,         *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2018 Ralf Habacker ralf.habacker @freenet.de
+
+    This file is part of libalkimia.
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "alkwebpage.h"
 
@@ -83,6 +72,11 @@ QString AlkWebPage::toHtml()
     return html;
 }
 
+void AlkWebPage::setContent(const QString &s)
+{
+    setHtml(s);
+}
+
 QString AlkWebPage::getFirstElement(const QString &symbol)
 {
     Q_UNUSED(symbol)
@@ -114,10 +108,17 @@ class AlkWebPage::Private
 public:
     QWebInspector *inspector;
     AlkWebPage *p;
+    QNetworkAccessManager *networkAccessManager;
     Private(AlkWebPage *parent)
       : inspector(nullptr),
-        p(parent)
+        p(parent),
+        networkAccessManager(new QNetworkAccessManager)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(5,9,0)
+        // see https://community.kde.org/Policies/API_to_Avoid#QNetworkAccessManager
+        networkAccessManager->setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
+#endif
+        p->page()->setNetworkAccessManager(networkAccessManager);
     }
 
     ~Private()
@@ -125,6 +126,7 @@ public:
         p->page()->settings()->setAttribute(QWebSettings::DeveloperExtrasEnabled, false);
         inspector->setPage(nullptr);
         delete inspector;
+        delete networkAccessManager;
     }
 
     void setWebInspectorEnabled(bool enable)
@@ -201,9 +203,11 @@ public:
 };
 
 AlkWebPage::AlkWebPage(QWidget *parent)
-  : QWidget(parent)
+  : QTextBrowser(parent)
   , d(new Private)
 {
+    setOpenExternalLinks(false);
+    setOpenLinks(false);
 }
 
 AlkWebPage::~AlkWebPage()
@@ -229,12 +233,7 @@ void AlkWebPage::setUrl(const QUrl &url)
 
 void AlkWebPage::setContent(const QString &s)
 {
-    Q_UNUSED(s)
-}
-
-QString AlkWebPage::toHtml()
-{
-    return QString();
+    setHtml(s);
 }
 
 QString AlkWebPage::getFirstElement(const QString &symbol)
