@@ -33,6 +33,10 @@
 #include <KHelpMenu>
 #include <QMenuBar>
 
+#if defined(Q_OS_WIN) && !defined(BUILD_WITH_KIO)
+#include <QNetworkProxyFactory>
+#endif
+
 int main(int argc, char **argv)
 {
     KAboutData about(QStringLiteral("onlinequoteseditor"),
@@ -50,6 +54,10 @@ int main(int argc, char **argv)
     KApplication app(true);
 #endif
 
+#if defined(Q_OS_WIN) && !defined(BUILD_WITH_KIO)
+    QNetworkProxyFactory::setUseSystemConfiguration(true);
+#endif
+
     MainWindow w;
 
 #if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
