@@ -1,21 +1,10 @@
-/***************************************************************************
- *   Copyright 2018 Ralf Habacker <ralf.habacker@freenet.de>               *
- *                                                                         *
- *   This file is part of libalkimia.                                      *
- *                                                                         *
- *   libalkimia is free software; you can redistribute it and/or           *
- *   modify it under the terms of the GNU General Public License           *
- *   as published by the Free Software Foundation; either version 2.1 of   *
- *   the License or (at your option) version 3 or any later version.       *
- *                                                                         *
- *   libalkimia is distributed in the hope that it will be useful,         *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2018 Ralf Habacker ralf.habacker @freenet.de
+
+    This file is part of libalkimia.
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
@@ -28,7 +17,7 @@
 #include <QComboBox>
 #include <QDockWidget>
 #include <QLineEdit>
-#include <QNetworkRequest>
+#include <QUrl>
 
 class MainWindow::Private
 {
@@ -50,7 +39,11 @@ public:
 
 void MainWindow::slotUrlChanged(const QUrl &url)
 {
+#if defined(BUILD_WITH_WEBKIT) || defined(BUILD_WITH_WEBENGINE)
     d->urlLine->setText(url.toString());
+#else
+    Q_UNUSED(url)
+#endif
 }
 
 void MainWindow::slotEditingFinished()
@@ -86,7 +79,6 @@ MainWindow::MainWindow(QWidget *parent)
     manager.addProfile(new AlkOnlineQuotesProfile("Finance::Quote", AlkOnlineQuotesProfile::Type::Script));
 #endif
     d->ui.setupUi(this);
-
     d->quotesWidget = new AlkOnlineQuotesWidget(true, true);
 
     QDockWidget *profilesWidget = new QDockWidget(i18n("Profiles"), this);
@@ -117,15 +109,14 @@ MainWindow::MainWindow(QWidget *parent)
     connect(&AlkOnlineQuotesProfileManager::instance(), SIGNAL(updateAvailable(const QString &, const QString &)),
             this, SLOT(slotUpdateAvailable(const QString &, const QString &)));
 
-#if defined(BUILD_WITH_WEBKIT) || defined(BUILD_WITH_WEBENGINE)
     manager.setWebPageEnabled(true);
     QDockWidget *browserWidget = new QDockWidget(i18n("Browser"), this);
     browserWidget->setObjectName("browserDockWidget");
     AlkWebPage *webPage = manager.webPage();
-    connect(webPage, SIGNAL(urlChanged(QUrl)), this, SLOT(slotUrlChanged(QUrl)));
 
-    // setup url line
     QHBoxLayout *hLayout = new QHBoxLayout;
+#if defined(BUILD_WITH_WEBKIT) || defined(BUILD_WITH_WEBENGINE)
+    // setup url line
     d->urlLine = new QLineEdit;
     connect(d->urlLine, SIGNAL(editingFinished()), this, SLOT(slotEditingFinished()));
     hLayout->addWidget(d->urlLine);
@@ -147,6 +138,9 @@ MainWindow::MainWindow(QWidget *parent)
     connect(box, SIGNAL(currentIndexChanged(QString)), this, SLOT(slotLanguageChanged(QString)));
     hLayout->addWidget(box);
 
+    webPage->setWebInspectorEnabled(true);
+    connect(webPage, SIGNAL(urlChanged(QUrl)), this, SLOT(slotUrlChanged(QUrl)));
+#endif
     // setup browser window
     QVBoxLayout *layout = new QVBoxLayout;
     layout->addLayout(hLayout);
@@ -155,8 +149,6 @@ MainWindow::MainWindow(QWidget *parent)
     group->setLayout(layout);
     browserWidget->setWidget(group);
     addDockWidget(Qt::RightDockWidgetArea, browserWidget);
-    webPage->setWebInspectorEnabled(true);
-#endif
 
     setCentralWidget(nullptr);
 
